==> vtk6-6.3.0-9-aarch64.pkg.tar.xz: vtk/vtkCommunity2DLayoutStrategy.java <==
// java wrapper for vtkCommunity2DLayoutStrategy object
//

package vtk;
import vtk.*;

public class vtkCommunity2DLayoutStrategy extends vtkGraphLayoutStrategy
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRandomSeed_2(int id0);
  public void SetRandomSeed(int id0)
    { SetRandomSeed_2(id0); }

  private native int GetRandomSeedMinValue_3();
  public int GetRandomSeedMinValue()
    { return GetRandomSeedMinValue_3(); }

  private native int GetRandomSeedMaxValue_4();
  public int GetRandomSeedMaxValue()
    { return GetRandomSeedMaxValue_4(); }

  private native int GetRandomSeed_5();
  public int GetRandomSeed()
    { return GetRandomSeed_5(); }

  private native void SetMaxNumberOfIterations_6(int id0);
  public void SetMaxNumberOfIterations(int id0)
    { SetMaxNumberOfIterations_6(id0); }

  private native int GetMaxNumberOfIterationsMinValue_7();
  public int GetMaxNumberOfIterationsMinValue()
    { return GetMaxNumberOfIterationsMinValue_7(); }

  private native int GetMaxNumberOfIterationsMaxValue_8();
  public int GetMaxNumberOfIterationsMaxValue()
    { return GetMaxNumberOfIterationsMaxValue_8(); }

  private native int GetMaxNumberOfIterations_9();
  public int GetMaxNumberOfIterations()
    { return GetMaxNumberOfIterations_9(); }

  private native void SetIterationsPerLayout_10(int id0);
  public void SetIterationsPerLayout(int id0)
    { SetIterationsPerLayout_10(id0); }

  private native int GetIterationsPerLayoutMinValue_11();
  public int GetIterationsPerLayoutMinValue()
    { return GetIterationsPerLayoutMinValue_11(); }

  private native int GetIterationsPerLayoutMaxValue_12();
  public int GetIterationsPerLayoutMaxValue()
    { return GetIterationsPerLayoutMaxValue_12(); }

  private native int GetIterationsPerLayout_13();
  public int GetIterationsPerLayout()
    { return GetIterationsPerLayout_13(); }

  private native void SetInitialTemperature_14(double id0);
  public void SetInitialTemperature(double id0)
    { SetInitialTemperature_14(id0); }

  private native double GetInitialTemperatureMinValue_15();
  public double GetInitialTemperatureMinValue()
    { return GetInitialTemperatureMinValue_15(); }

  private native double GetInitialTemperatureMaxValue_16();
  public double GetInitialTemperatureMaxValue()
    { return GetInitialTemperatureMaxValue_16(); }

  private native double GetInitialTemperature_17();
  public double GetInitialTemperature()
    { return GetInitialTemperature_17(); }

  private native void SetCoolDownRate_18(double id0);
  public void SetCoolDownRate(double id0)
    { SetCoolDownRate_18(id0); }

  private native double GetCoolDownRateMinValue_19();
  public double GetCoolDownRateMinValue()
    { return GetCoolDownRateMinValue_19(); }

  private native double GetCoolDownRateMaxValue_20();
  public double GetCoolDownRateMaxValue()
    { return GetCoolDownRateMaxValue_20(); }

  private native double GetCoolDownRate_21();
  public double GetCoolDownRate()
    { return GetCoolDownRate_21(); }

  private native void SetRestDistance_22(double id0);
  public void SetRestDistance(double id0)
    { SetRestDistance_22(id0); }

  private native double GetRestDistance_23();
  public double GetRestDistance()
    { return GetRestDistance_23(); }

  private native void Initialize_24();
  public void Initialize()
    { Initialize_24(); }

  private native void Layout_25();
  public void Layout()
    { Layout_25(); }

  private native int IsLayoutComplete_26();
  public int IsLayoutComplete()
    { return IsLayoutComplete_26(); }

  private native String GetCommunityArrayName_27();
  public String GetCommunityArrayName()
    { return GetCommunityArrayName_27(); }

  private native void SetCommunityArrayName_28(String id0);
  public void SetCommunityArrayName(String id0)
    { SetCommunityArrayName_28(id0); }

  private native void SetCommunityStrength_29(double id0);
  public void SetCommunityStrength(double id0)
    { SetCommunityStrength_29(id0); }

  private native double GetCommunityStrengthMinValue_30();
  public double GetCommunityStrengthMinValue()
    { return GetCommunityStrengthMinValue_30(); }

  private native double GetCommunityStrengthMaxValue_31();
  public double GetCommunityStrengthMaxValue()
    { return GetCommunityStrengthMaxValue_31(); }

  private native double GetCommunityStrength_32();
  public double GetCommunityStrength()
    { return GetCommunityStrength_32(); }

  public vtkCommunity2DLayoutStrategy() { super(); }

  public vtkCommunity2DLayoutStrategy(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkCommunity2DLayoutStrategy.java <==
// java wrapper for vtkCommunity2DLayoutStrategy object
//

package vtk;
import vtk.*;

public class vtkCommunity2DLayoutStrategy extends vtkGraphLayoutStrategy
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRandomSeed_2(int id0);
  public void SetRandomSeed(int id0)
    { SetRandomSeed_2(id0); }

  private native int GetRandomSeedMinValue_3();
  public int GetRandomSeedMinValue()
    { return GetRandomSeedMinValue_3(); }

  private native int GetRandomSeedMaxValue_4();
  public int GetRandomSeedMaxValue()
    { return GetRandomSeedMaxValue_4(); }

  private native int GetRandomSeed_5();
  public int GetRandomSeed()
    { return GetRandomSeed_5(); }

  private native void SetMaxNumberOfIterations_6(int id0);
  public void SetMaxNumberOfIterations(int id0)
    { SetMaxNumberOfIterations_6(id0); }

  private native int GetMaxNumberOfIterationsMinValue_7();
  public int GetMaxNumberOfIterationsMinValue()
    { return GetMaxNumberOfIterationsMinValue_7(); }

  private native int GetMaxNumberOfIterationsMaxValue_8();
  public int GetMaxNumberOfIterationsMaxValue()
    { return GetMaxNumberOfIterationsMaxValue_8(); }

  private native int GetMaxNumberOfIterations_9();
  public int GetMaxNumberOfIterations()
    { return GetMaxNumberOfIterations_9(); }

  private native void SetIterationsPerLayout_10(int id0);
  public void SetIterationsPerLayout(int id0)
    { SetIterationsPerLayout_10(id0); }

  private native int GetIterationsPerLayoutMinValue_11();
  public int GetIterationsPerLayoutMinValue()
    { return GetIterationsPerLayoutMinValue_11(); }

  private native int GetIterationsPerLayoutMaxValue_12();
  public int GetIterationsPerLayoutMaxValue()
    { return GetIterationsPerLayoutMaxValue_12(); }

  private native int GetIterationsPerLayout_13();
  public int GetIterationsPerLayout()
    { return GetIterationsPerLayout_13(); }

  private native void SetInitialTemperature_14(double id0);
  public void SetInitialTemperature(double id0)
    { SetInitialTemperature_14(id0); }

  private native double GetInitialTemperatureMinValue_15();
  public double GetInitialTemperatureMinValue()
    { return GetInitialTemperatureMinValue_15(); }

  private native double GetInitialTemperatureMaxValue_16();
  public double GetInitialTemperatureMaxValue()
    { return GetInitialTemperatureMaxValue_16(); }

  private native double GetInitialTemperature_17();
  public double GetInitialTemperature()
    { return GetInitialTemperature_17(); }

  private native void SetCoolDownRate_18(double id0);
  public void SetCoolDownRate(double id0)
    { SetCoolDownRate_18(id0); }

  private native double GetCoolDownRateMinValue_19();
  public double GetCoolDownRateMinValue()
    { return GetCoolDownRateMinValue_19(); }

  private native double GetCoolDownRateMaxValue_20();
  public double GetCoolDownRateMaxValue()
    { return GetCoolDownRateMaxValue_20(); }

  private native double GetCoolDownRate_21();
  public double GetCoolDownRate()
    { return GetCoolDownRate_21(); }

  private native void SetRestDistance_22(double id0);
  public void SetRestDistance(double id0)
    { SetRestDistance_22(id0); }

  private native double GetRestDistance_23();
  public double GetRestDistance()
    { return GetRestDistance_23(); }

  private native void Initialize_24();
  public void Initialize()
    { Initialize_24(); }

  private native void Layout_25();
  public void Layout()
    { Layout_25(); }

  private native int IsLayoutComplete_26();
  public int IsLayoutComplete()
    { return IsLayoutComplete_26(); }

  private native String GetCommunityArrayName_27();
  public String GetCommunityArrayName()
    { return GetCommunityArrayName_27(); }

  private native void SetCommunityArrayName_28(String id0);
  public void SetCommunityArrayName(String id0)
    { SetCommunityArrayName_28(id0); }

  private native void SetCommunityStrength_29(double id0);
  public void SetCommunityStrength(double id0)
    { SetCommunityStrength_29(id0); }

  private native double GetCommunityStrengthMinValue_30();
  public double GetCommunityStrengthMinValue()
    { return GetCommunityStrengthMinValue_30(); }

  private native double GetCommunityStrengthMaxValue_31();
  public double GetCommunityStrengthMaxValue()
    { return GetCommunityStrengthMaxValue_31(); }

  private native double GetCommunityStrength_32();
  public double GetCommunityStrength()
    { return GetCommunityStrength_32(); }

  public vtkCommunity2DLayoutStrategy() { super(); }

  public vtkCommunity2DLayoutStrategy(long id) { super(id); }
  public native long   VTKInit();

}
